/*=================== FILE ABSTRACT ==========================================
 *
 * Synopsis::         Source for numeric textfield validation class
 *
 * File Name::        %M%
 * Version::          %I%
 * Type::             source
 * Date Completed::   %G%
 *
 * Environment::
 *     Language::     Java
 *     Computer::     Compaq/Alpha
 *     OS::           DigitalUNIX
 *     OSVersion::    4.0
 *
 * Module Information::
 *     Owner::        MDACC
 *     Department::   Biostatistics
 *     Researcher::   N/A
 *     Application::  <generic>
 *
 *============================================================================*/

/*
 * @(#)NumericValidator.java    1.0 2000/12/27
 *
 * Copyright (c) 2000 M.D. Anderson Cancer Center
 * 1515 Holcombe, Houston, TX, 77030, U.S.A.
 * All rights reserved.
 */

package org.mdanderson.biostat.util;


/**
 * NumericValidator - Implements numeric validation.
 *
 * @version 1.0 2000/12/27
 * @author <a href="mailto:roebuck@mdanderson.org">P. Roebuck</a>
 */
public class NumericValidator extends ValidationAdapter
{
    // =========================================================================
    // PUBLIC INTERFACE
    // =========================================================================

    /**
     * Sets the allowed range of values
     *
     * @param min  minimum double value allowed (inclusive)
     * @param max  maximum double value allowed (inclusive)
     */
    public void setRange(double min, double max)
    {
        this.min = min;
        this.max = max;
    }

    // =========================================================================
    // IMPLEMENTS VALIDATOR
    // =========================================================================

    /**
     * Determines the validity of numeric data. Converts the value to a double
     * and ensures it falls within the accepted range.
     *
     * @param value  object with data to be checked
     * @return       true if data is valid; otherwise, false
     */
    public boolean isValid(Object value)
    {
        boolean valid = false;

        if (value != null)
        {
            try
            {
                double d = Double.parseDouble(value.toString());

                valid = ((d >= min) && (d <= max));
            }
            catch (NumberFormatException e)
            {
                // Ignore since this is what we're checking to start with
            }
        }

        return valid;
    }

    // =========================================================================
    // CLASS INTERFACE
    // =========================================================================

    /**
     * Convenience function that determines the validity of numeric data
     * without the caller having to have an instance of this class available.
     *
     * @param value  data to be checked
     * @return       true if data is valid; otherwise, false
     * @see #isValid
     */
    public static boolean accepts(Object value)
    {
        return new NumericValidator().isValid(value);
    }

    // =========================================================================
    // OBJECT ATTRIBUTES
    // =========================================================================

    double min = Double.MIN_VALUE;
    double max = Double.MAX_VALUE;
}

