##################### FILE ABSTRACT ############################################
##
## Synopsis::         Source for Demo Plaid 1e model routines
##
## File Name::        %M%
## Version::          %I%
## Type::             source
## Date Completed::   %G%
##
## Environment::
##     Language::     Splus
##     Computer::     Compaq/Alpha
##     OS::           DigitalUNIX
##     OSVersion::    4.0
##
## Module Information::
##     Owner::        MDACC
##     Department::   Biostatistics
##     Researcher::   Kim-Anh Do
##     Application::  geneclust
##
################################################################################

Plaid1e.func<-function(N,p,amplitude)
{
## Creates a plaid type matrix with 3 non overlapping clusters
## and overlayed Gaussian noise

    # Check matrix size constraints
    minN<-30;
    minp<-30;
    if (is.numeric(N) && N < minN)
        stop(paste("#rows =",N,", min =",minN,"\n"));
    if (is.numeric(p) && p < minp)
        stop(paste("#columns =",p,", min =",minp,"\n"));

    # Amplitude of the clusters
    a<- c(rep(amplitude,3));
    # Size of each cluster in "genes"(rows)
    n<-c(as.integer(N/3),as.integer(N/2),as.integer(N-(N/3+N/2)-1));
    # Size of each cluster in "cells"(cols)
    r<-c(as.integer(p*0.8),as.integer(p*0.8),as.integer(p*0.6));
    # Beginning row of each cluster
    nb<-c(1,as.integer(N/3)+1,as.integer(N/3+N/2)+1);

    second<-as.integer(p-r[2]);
    third <-as.integer(p-r[3]);

    X<-matrix(0,nrow=N,ncol=p);

    X[nb[1]:(nb[1]+n[1]),1:r[1]]<-a[1]
    X[nb[2]:(nb[2]+n[2]),second:p]<-a[2]
    X[nb[3]:(nb[3]+n[3]),third:p]<-a[3]

    return(X);
}

GCDemoPlaid1e.func<-function(nclst,percentToShave,nperm,gapTolerance,N,p,a,
                             noise,df,percentSupervision,classificationFileName)
{
    cat("PK_MONITOR_CREATE_MATRIX\n");

    X<-Plaid1e.func(N,p,a);
    Data<-Common.func(X,
                      N,
                      p,
                      nclst,
                      percentToShave,
                      nperm,
                      gapTolerance,
                      noise,
                      df,
                      percentSupervision,
                      classificationFileName);

    return(Data);
}

