#################### FILE ABSTRACT ############################################
##
## Synopsis::         Source for common routines
##
## File Name::        %M%
## Version::          %I%
## Type::             source
## Date Completed::   %G%
##
## Environment::
##     Language::     Splus
##     Computer::     Compaq/Alpha
##     OS::           DigitalUNIX
##     OSVersion::    4.0
##
## Module Information::
##     Owner::        MDACC
##     Department::   Biostatistics
##     Researcher::   Kim-Anh Do
##     Application::  geneclust
##
###############################################################################


if (GCinterpreter == "R") {

	AsciiToInt <- function(s) { return (as.integer(s)); }
	get.message <- function() { return ("unknown"); }
	dump.calls <- traceback;
	q <- function() { return (quit ("no")); }
}

##*****************************************************************************
GetAbsPathName.func<-function(pathname)
{
    ## Test if path is relative or absolute
    firstchar<-substring(pathname,1,1);
    if (firstchar == "/")
        abspathname<-pathname
    else
        abspathname<-paste(GCinstall,pathname,sep="/");

    return(abspathname);
}


##******************************************************************************
ErrorHandler.func<-function()
{
    cat("PK_MONITOR_APP_TERMINATED\n");
    cat(paste("PK_MONITOR_ERR_FATAL ",get.message(),"\n",sep=""));
    dump.calls();
}



##******************************************************************************
SaveData.func<-function(data)
{

    ## Save matrix to a text file/data frame
    matrixfile <-paste(GCoutput,"GCMatrix.txt",sep="/");
    write.table(data$C,file=matrixfile,sep="\t");
    ## Save matrix to a binary file
    matrixfile <-paste(GCoutput,"GCMatrix.dat",sep="/");
    save (data, file=matrixfile);

    # Store col and row labels of the table into the appropriate files
    outfileCol<-paste(GCoutput,"ColLbls.txt",sep="/");
    outfileRow<-paste(GCoutput,"RowLbls.txt",sep="/");

    GenerateLabels.func(data, outfileCol, outfileRow);
    cat ("SaveData.func completed\n");

}

##***************************************************************************
GenerateLabels.func<-function(data,outfileCol,outfileRow)
{
    # Label processing
    if (is.null(data$colLabels) == TRUE) {
        data$colLabels<-paste("Sample",c(1:data$p),sep="");
    }
    cat("data$colLabels = ", data$colLabels, "\n");
    write(data$colLabels,file=outfileCol);

    if (is.null(data$rowLabels) == TRUE) {
        data$rowLabels<-paste("GENE",c(1:data$N),sep="");
    }
    cat("data$rowLabels = ", data$rowLabels, "\n");
    write(data$rowLabels,file=outfileRow);
}

