/*=================== FILE ABSTRACT ==========================================
 *
 * Synopsis::         Public header for gene clustering routines
 *
 * File Name::        %M%
 * Version::          %I%
 * Type::             include
 * Date Completed::   %G%
 *
 * Environment::
 *     Language::     ANSI C
 *     Computer::     Compaq/Alpha
 *     OS::           DigitalUNIX
 *     OSVersion::    4.0
 *
 * Module Information::
 *     Owner::        MDACC
 *     Department::   Biostatistics
 *     Researcher::   Kim-Anh Do
 *     Application::  geneclust
 *
 *============================================================================*/
/* %W% %G% %U% */

#ifndef GENECLUST_H
#define GENECLUST_H	1

#include "GeneClust_types.h"
#include "splus.h"
#include "cplusplus.h"


/*
 * Pathname Defines
 */
#define FILE_COL_LABELS                     "ColLbls.txt"
#define FILE_ROW_LABELS                     "RowLbls.txt"
#define FILE_CLUSTER_LENGTHS                "clusterlengths.txt"
#define FILE_MATRIX_VALUES                  "matrix.txt"
#define FILE_CLUSTERS                       "clusters.txt"
#define FILE_CLUSTER_LABELS                 "clabels.txt"
#define FILE_EIGENVALUE_LABELS              "elabels.txt"
#define FILE_GAP_LABELS                     "glabels.txt"
#define FILE_ORIG_MATRIX_VALUES             "origmatrix.txt"
#define FILE_PRINCIPAL_COMPONENT_LABELS     "pclabels.txt"
#define FILE_VARIANCE_LABELS                "vlabels.txt"
#define RELPATH_OUTPUT_DIRECTORY            "output/"


/*
 * Environment Variable Defines
 */
#define ENVVAR_GCHOME                       "GCHOME"
#define ENVVAR_GCOUTPUT                     "GCOUTPUT"


/*
 * Java Property Key Defines
 */
#define PREFIX                             "PK_MONITOR_"
#define ABEND                               PREFIX"APP_TERMINATED"
#define REPORT_ERROR                        PREFIX"ERR_FATAL"
#define REPORT_WARNING                      PREFIX"ERR_RECOVERABLE"
#define NO_CLUSTERS_LEFT                    PREFIX"ERR_NO_CLUSTERS_LEFT"
#define EXTRACT_CLUSTER                     PREFIX"EXTRACT_CLUSTER"
#define SHAVE_INIT_NESTED_SEQUENCE          PREFIX"SHAVE_INIT_NESTED_SEQUENCE"
#define SHAVE_RAND_NESTED_SEQUENCE          PREFIX"SHAVE_RAND_NESTED_SEQUENCE"
#define RANDOMIZE_MATRIX                    PREFIX"RANDOMIZE_MATRIX"
#define ESTIMATE_OPT_CLUSTER_SIZE           PREFIX"ESTIMATE_OPT_CLUSTER_SIZE"
#define ORTHOGONALIZE_MATRIX                PREFIX"ORTHOGONALIZE_MATRIX"


BEGIN_EXTERN_C
/*
 * Function Declarations
 */
extern void Abend (
  const char *message);

extern void GeneShave (
  SCharacter_t *outputDirectoryName,
  SInteger_t *numClusters,
  SInteger_t *percentToShave,
  SInteger_t *numPermutations,
  SInteger_t *gapTolerance,
  SDouble_t  *V,
  SInteger_t *N,
  SInteger_t *p,
  SLogical_t *verbose,
  SLogical_t *generateLabels,
  SLogical_t *writeMatrix,
  SInteger_t *percentSupervision,
  SCharacter_t *classificationFileName,
  SInteger_t *numClustersExtracted);

extern void SetOutputDirectory (const char *dirName);
extern const char *GetOutputDirectory (void);
END_EXTERN_C

#endif /* GENECLUST_H */

